-------------------------------------------------------------------------------
-- HEIG-VD, Haute Ecole d'Ingenierie et de Gestion du canton de Vaud
-- Institut REDS, Reconfigurable & Embedded Digital Systems
--
-- Fichier      : spi_master_tb.vhd
--
-- Description  : SPI master interface testbench
--
-- Auteur       :
-- Date         :
-- Version      :
--
--
--| Modifications |------------------------------------------------------------
-- Version   Auteur Date               Description
--
-------------------------------------------------------------------------------

library ieee;
    context ieee.ieee_std_context;

entity spi_master_tb is
    generic (N_TRANSMISSIONS : integer := 1);
end spi_master_tb;

architecture testbench of spi_master_tb is

    component spi_master is
      generic
      (
        N         : integer   :=  8;
        CLK_DIV   : integer   := 100
      );
      port
      (
        clk_i           : in  std_logic;
        rst_i           : in  std_logic;
        tx_start_i      : in  std_logic;
        tx_end_o        : out std_logic;
        data_parallel_i : in  std_logic_vector(N-1 downto 0);
        data_parallel_o : out std_logic_vector(N-1 downto 0);
        sclk_o          : out std_logic;
        n_ss_o          : out std_logic;
        mosi_o          : out std_logic;
        miso_i          : in  std_logic
      );
    end component;

    -- Nombre de bits des mots à transmettre
    constant N       : integer   :=  8;
    -- Diviseur d'horloge
    constant CLK_DIV : integer   :=  2;

    signal clk_s             : std_logic;
    signal rst_s             : std_logic;
    signal tx_start_sti      : std_logic;
    signal tx_end_obs        : std_logic;
    signal data_parallel_sti : std_logic_vector(N-1 downto 0);
    signal data_parallel_obs : std_logic_vector(N-1 downto 0);
    signal sclk_obs          : std_logic;
    signal n_ss_obs          : std_logic;
    signal mosi_obs          : std_logic;
    signal miso_sti          : std_logic;


begin

    -- A compléter

    dut : spi_master
      generic map
      (
        N         => N,
        CLK_DIV   => CLK_DIV
      )
      port map
      (
        clk_i           => clk_s,
        rst_i           => rst_s,
        tx_start_i      => tx_start_sti,
        tx_end_o        => tx_end_obs,
        data_parallel_i => data_parallel_sti,
        data_parallel_o => data_parallel_obs,
        sclk_o          => sclk_obs,
        n_ss_o          => n_ss_obs,
        mosi_o          => mosi_obs,
        miso_i          => miso_sti
        );

end testbench;
